package dk.nsp.idsas.dao;

import dk.nsp.idsas.dao.entity.OrganisationBlurringEntity;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;

import javax.sql.DataSource;
import java.sql.Timestamp;
import java.util.HashMap;
import java.util.List;

public class OrganisationBlurringDao {
    private final NamedParameterJdbcTemplate jdbcTemplate;
    private final BeanPropertyRowMapper<OrganisationBlurringEntity> rowMapper;

    public OrganisationBlurringDao(DataSource dataSource) {
        jdbcTemplate = new NamedParameterJdbcTemplate(dataSource);
        rowMapper = BeanPropertyRowMapper.newInstance(OrganisationBlurringEntity.class);
    }

    public void insert(OrganisationBlurringEntity organisationBlurringEntity) {
        String query = "INSERT INTO organisation_blurring(organisation_id, organisation_id_type, creator_cvr, validFrom, validTo)" +
                " VALUES (:organisation_id, :organisation_id_type, :creator_cvr, :validFrom, :validTo)";
        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put("organisation_id", organisationBlurringEntity.getOrganisationId());
        parameters.put("organisation_id_type", organisationBlurringEntity.getOrganisationIdType());
        parameters.put("creator_cvr", organisationBlurringEntity.getCreatorCvr());
        parameters.put("validFrom", Timestamp.from(organisationBlurringEntity.getValidFrom()));
        parameters.put("validTo", Timestamp.from(organisationBlurringEntity.getValidTo()));

        jdbcTemplate.update(query, parameters);
    }

    public List<OrganisationBlurringEntity> getActiveOrganisationBlurrings(String createdCvr) {
        String query = "SELECT organisation_id, organisation_id_type\n" +
                "FROM organisation_blurring\n" +
                "WHERE creator_cvr = :creator_cvr\n" +
                "AND validFrom < NOW()\n" +
                "AND validTo > NOW();";

        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put("creator_cvr", createdCvr);
        return jdbcTemplate.query(query, parameters, rowMapper);
    }

    public List<OrganisationBlurringEntity> getAllOrganisationBlurrings(String createdCvr) {
        String query = "SELECT organisation_id, organisation_id_type\n" +
                "FROM organisation_blurring\n" +
                "WHERE creator_cvr = :creator_cvr;";

        HashMap<String, Object> parameters = new HashMap<>();
        parameters.put("creator_cvr", createdCvr);
        return jdbcTemplate.query(query, parameters, rowMapper);
    }
}
